@@ -1040,6 +1040,9 @@ class Work(Base):
         result.logger = logger
         return result
 
+    def depend_on(self, work):
+        return False
+
     def generate_work_from_template(self):
         logger = self.logger
         self.logger = None
@@ -1271,8 +1274,9 @@ class Work(Base):
                 < datetime.datetime.utcnow()):                                                                        # noqa: W503
 
                 if (processing and processing.status
-                    and processing.status not in [ProcessingStatus.New, ProcessingStatus.New.value,                   # noqa: W503
-                                                  ProcessingStatus.Submitting, ProcessingStatus.Submitting.value]):   # noqa: W503
+                    and processing.status not in [ProcessingStatus.New, ProcessingStatus.New.value]):                   # noqa: W503
+                    # and processing.status not in [ProcessingStatus.New, ProcessingStatus.New.value,                   # noqa: W503
+                    #                               ProcessingStatus.Submitting, ProcessingStatus.Submitting.value]):   # noqa: W503
                     return True
             return False
         return True
